==> dojo-1.10.6.tgz: package/cldr/nls/bs/generic.js <==
define(
//begin v1.x content
{
	"dateFormatItem-yyyyMMMEd": "E, dd. MMM y. G",
	"field-dayperiod": "pre podne/ popodne",
	"field-minute": "minut",
	"dateFormatItem-MMMEd": "E, dd. MMM",
	"field-day-relative+-1": "juče",
	"dateFormatItem-hms": "hh:mm:ss a",
	"field-day-relative+-2": "prekjuče",
	"field-weekday": "dan u nedelji",
	"dateFormatItem-MMM": "LLL",
	"field-era": "era",
	"dateFormatItem-Gy": "y. G",
	"field-hour": "čas",
	"dateFormatItem-y": "y. G",
	"dateFormatItem-yyyy": "y. G",
	"dateFormatItem-Ed": "E, dd.",
	"field-day-relative+0": "danas",
	"field-day-relative+1": "sutra",
	"field-day-relative+2": "prekosutra",
	"dateFormatItem-GyMMMd": "dd. MMM y. G",
	"dateFormat-long": "dd. MMMM y. G",
	"field-zone": "zona",
	"dateFormatItem-Hm": "HH:mm",
	"dateFormat-medium": "dd.MM.y. G",
	"dateFormatItem-Hms": "HH:mm:ss",
	"dateFormatItem-ms": "mm:ss",
	"field-year": "godina",
	"dateFormatItem-yyyyQQQQ": "G y QQQQ",
	"field-week": "nedelja",
	"dateFormatItem-yyyyMd": "dd.MM.y. G",
	"dateFormatItem-yyyyMMMd": "dd. MMM y. G",
	"dateFormatItem-yyyyMEd": "E, dd.MM.y. G",
	"dateFormatItem-MMMd": "dd. MMM",
	"field-month": "mesec",
	"dateFormatItem-M": "L",
	"field-second": "sekund",
	"dateFormatItem-GyMMMEd": "E, dd. MMM y. G",
	"dateFormatItem-GyMMM": "MMM y. G",
	"field-day": "dan",
	"dateFormatItem-yyyyQQQ": "G y QQQ",
	"dateFormatItem-MEd": "E, dd.MM.",
	"dateFormatItem-hm": "hh:mm a",
	"dateFormat-short": "dd.MM.y. GGGGG",
	"dateFormatItem-yyyyM": "MM.y. G",
	"dateFormat-full": "EEEE, dd. MMMM y. G",
	"dateFormatItem-Md": "dd.MM.",
	"dateFormatItem-yyyyMMM": "MMM y. G",
	"dateFormatItem-d": "d"
}
//end v1.x content
);

==> dojo-1.14.2.tgz: package/cldr/nls/bs/generic.js <==
define(
//begin v1.x content
{
	"dateFormatItem-yyyyMMMEd": "E, dd. MMM y. G",
	"field-dayperiod": "prijepodne/poslijepodne",
	"field-minute": "minut",
	"dateFormatItem-MMMEd": "E, dd. MMM",
	"field-day-relative+-1": "juče",
	"dateFormatItem-hms": "hh:mm:ss a",
	"field-day-relative+-2": "prekjuče",
	"field-weekday": "dan u sedmici",
	"dateFormatItem-MMM": "LLL",
	"field-era": "era",
	"dateFormatItem-Gy": "y. G",
	"field-hour": "sat",
	"dateFormatItem-y": "y. G",
	"dateFormatItem-yyyy": "y. G",
	"dateFormatItem-Ed": "E, dd.",
	"field-day-relative+0": "danas",
	"field-day-relative+1": "sutra",
	"field-day-relative+2": "prekosutra",
	"dateFormatItem-GyMMMd": "dd. MMM y. G",
	"dateFormat-long": "dd. MMMM y. G",
	"field-zone": "zona",
	"dateFormatItem-Hm": "HH:mm",
	"dateFormat-medium": "dd.MM.y. G",
	"dateFormatItem-Hms": "HH:mm:ss",
	"dateFormatItem-ms": "mm:ss",
	"field-year": "godina",
	"dateFormatItem-yyyyQQQQ": "G y QQQQ",
	"field-week": "sedmica",
	"dateFormatItem-yyyyMd": "dd.MM.y. G",
	"dateFormatItem-yyyyMMMd": "dd. MMM y. G",
	"dateFormatItem-yyyyMEd": "E, dd.MM.y. G",
	"dateFormatItem-MMMd": "dd. MMM",
	"field-month": "mjesec",
	"dateFormatItem-M": "L",
	"field-second": "sekund",
	"dateFormatItem-GyMMMEd": "E, dd. MMM y. G",
	"dateFormatItem-GyMMM": "MMM y. G",
	"field-day": "dan",
	"dateFormatItem-yyyyQQQ": "G y QQQ",
	"dateFormatItem-MEd": "E, dd.MM.",
	"dateFormatItem-hm": "hh:mm a",
	"dateFormat-short": "dd.MM.y. GGGGG",
	"dateFormatItem-yyyyM": "MM.y. G",
	"dateFormat-full": "EEEE, dd. MMMM y. G",
	"dateFormatItem-Md": "dd.MM.",
	"dateFormatItem-yyyyMMM": "MMM y. G",
	"dateFormatItem-d": "d"
}
//end v1.x content
);
